/*!
 * Vue-intercom v1.0.0
 * (c) 2019-2024 Mathieu Stanowski
 */
import { reactive, inject } from 'vue';
import Intercom from '@mathieustan/intercom';

// Utilities

// Types

var IntercomSymbol = Symbol["for"]('vue-intercom');
function initIntercom() {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var appId = options.appId;
  var intercom = reactive(new Intercom({
    appId: appId
  }));

  // CF => https://developers.intercom.com/installing-intercom/docs/basic-javascript
  if (typeof window.Intercom === 'function') {
    intercom.init();
    intercom.callIntercom('reattach_activator');
    intercom.update();
  } else {
    var placeholder = function placeholder() {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }
      return placeholder.c(args);
    };
    placeholder.q = [];
    placeholder.c = function (args) {
      return placeholder.q.push(args);
    };
    window.Intercom = placeholder;
  }
  return intercom;
}
function useIntercom() {
  var intercom = inject(IntercomSymbol);
  if (!intercom) throw new Error('[VueIntercom] Could not find intercom injection');
  return intercom;
}

// Composables
function createIntercom(options) {
  var intercom = initIntercom(options != null ? options : {});
  var install = function install(app) {
    app.provide(IntercomSymbol, intercom);
    app.config.globalProperties.$intercom = intercom;
    app.mixin({
      computed: {
        $intercom: function $intercom() {
          return intercom;
        }
      }
    });
  };
  return {
    install: install,
    intercom: intercom
  };
}
var version = "1.0.0";
createIntercom.version = version;

export { IntercomSymbol, createIntercom, initIntercom, useIntercom, version };
