/*!
 * Vue-intercom v1.0.0
 * (c) 2019-2024 Mathieu Stanowski
 */
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue'), require('@mathieustan/intercom')) :
  typeof define === 'function' && define.amd ? define(['exports', 'vue', '@mathieustan/intercom'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.VueIntercom = {}, global.Vue, global.Intercom));
})(this, (function (exports, vue, Intercom) { 'use strict';

  function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e : { default: e }; }

  var Intercom__default = /*#__PURE__*/_interopDefaultCompat(Intercom);

  // Utilities

  // Types

  var IntercomSymbol = Symbol["for"]('vue-intercom');
  function initIntercom() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var appId = options.appId;
    var intercom = vue.reactive(new Intercom__default.default({
      appId: appId
    }));

    // CF => https://developers.intercom.com/installing-intercom/docs/basic-javascript
    if (typeof window.Intercom === 'function') {
      intercom.init();
      intercom.callIntercom('reattach_activator');
      intercom.update();
    } else {
      var placeholder = function placeholder() {
        for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }
        return placeholder.c(args);
      };
      placeholder.q = [];
      placeholder.c = function (args) {
        return placeholder.q.push(args);
      };
      window.Intercom = placeholder;
    }
    return intercom;
  }
  function useIntercom() {
    var intercom = vue.inject(IntercomSymbol);
    if (!intercom) throw new Error('[VueIntercom] Could not find intercom injection');
    return intercom;
  }

  // Composables
  function createIntercom(options) {
    var intercom = initIntercom(options != null ? options : {});
    var install = function install(app) {
      app.provide(IntercomSymbol, intercom);
      app.config.globalProperties.$intercom = intercom;
      app.mixin({
        computed: {
          $intercom: function $intercom() {
            return intercom;
          }
        }
      });
    };
    return {
      install: install,
      intercom: intercom
    };
  }
  var version = "1.0.0";
  createIntercom.version = version;

  exports.IntercomSymbol = IntercomSymbol;
  exports.createIntercom = createIntercom;
  exports.initIntercom = initIntercom;
  exports.useIntercom = useIntercom;
  exports.version = version;

}));
